@@ -36,6 +36,7 @@ import org.apache.cordova.CallbackContext;
 import org.apache.cordova.CordovaInterface;
 import org.apache.cordova.CordovaPlugin;
 import org.apache.cordova.CordovaPluginPathHandler;
+import org.apache.cordova.CordovaResourceApi;
 import org.apache.cordova.CordovaWebView;
 import org.apache.cordova.LOG;
 import org.apache.cordova.PermissionHelper;
@@ -1240,6 +1241,8 @@ public class FileUtils extends CordovaPlugin {
     }
 
     public CordovaPluginPathHandler getPathHandler() {
+        final CordovaResourceApi resourceApi = webView.getResourceApi();
+
         WebViewAssetLoader.PathHandler pathHandler = path -> {
             String targetFileSystem = null;
 
@@ -1263,9 +1266,11 @@ public class FileUtils extends CordovaPlugin {
                 targetFileSystem = "cache-external";
             } else if (path.startsWith(LocalFilesystemURL.fsNameToCdvKeyword("assets"))) {
                 targetFileSystem = "assets";
+            } else if (path.startsWith(LocalFilesystemURL.fsNameToCdvKeyword("content"))) {
+                targetFileSystem = "content";
             }
 
-            boolean isAssetsFS = targetFileSystem == "assets";
+            boolean isAssetsFS = "assets".equals(targetFileSystem);
 
             if (targetFileSystem != null) {
                 // Loop the registered file systems to find the target.
@@ -1279,26 +1284,46 @@ public class FileUtils extends CordovaPlugin {
                      */
                     if (fileSystem.name.equals(targetFileSystem)) {
                         // E.g. replace __cdvfile_persistent__ with native path "/data/user/0/com.example.file/files/files/"
+
+                        if ("content".equals(targetFileSystem)) {
+                            // The WebviewAssetLoader uses getPath API, which gives us a decoded path
+                            // For content paths however, we need it to remain encoded.
+                            // The Uri.encode API will encode forward slashes, therefore we must
+                            // split the path, encode each segment, and rebuild the path
+                            String[] pathParts = path.split("/");
+                            path = "";
+                            for (String part : pathParts) {
+                                if ("".equals(path)) {
+                                    path = Uri.encode(part);
+                                }
+                                else {
+                                    path += "/" + Uri.encode(part);
+                                }
+                            }
+                        }
+
                         String fileSystemNativeUri = fileSystem.rootUri.toString().replace("file://", "");
                         String fileTarget = path.replace(LocalFilesystemURL.fsNameToCdvKeyword(targetFileSystem) + "/", fileSystemNativeUri);
-                        File file = null;
 
                         if (isAssetsFS) {
                             fileTarget = fileTarget.replace("/android_asset/", "");
-                        } else {
-                            file = new File(fileTarget);
                         }
 
+                        Uri fileUri = Uri.parse(fileTarget);
+                        String mimeType = null;
+
                         try {
-                            InputStream fileIS = !isAssetsFS ?
-                                    new FileInputStream(file) :
-                                    webView.getContext().getAssets().open(fileTarget);
+                            InputStream io = null;
+                            if (isAssetsFS) {
+                                io = webView.getContext().getAssets().open(fileTarget);
+                                mimeType = getMimeType(fileUri);
+                            } else {
+                                CordovaResourceApi.OpenForReadResult resource = resourceApi.openForRead(fileUri);
+                                io = resource.inputStream;
+                                mimeType = resource.mimeType;
+                            }
 
-                            String filePath = !isAssetsFS ? file.toString() : fileTarget;
-                            Uri fileUri = Uri.parse(filePath);
-                            String fileMimeType = getMimeType(fileUri);
-
-                            return new WebResourceResponse(fileMimeType, null, fileIS);
+                            return new WebResourceResponse(mimeType, null, io);
                         } catch (FileNotFoundException e) {
                             Log.e(LOG_TAG, e.getMessage());
                         } catch (IOException e) {
